@@ -53,7 +53,7 @@ class EncoderLoader(object):
     @staticmethod
     def load_tokenizer(model_id, region='us'):
         bucket = CloudBucket(region)
-        model_dir = bucket.download_config('tokenizers', model_id)
+        model_dir = bucket.download_tokenizer('tokenizers', model_id, local_dir="resources")
         config = json.load(open(os.path.join(model_dir, 'config.json')))
         return Tokenizer(model_id, region, config.get("tokenizer"))
 
